# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-31 16:26
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oidc_provider', '0021_refresh_token_not_unique'),
    ]

    operations = [
        migrations.AddField(
            model_name='client',
            name='require_consent',
            field=models.BooleanField(
                default=True,
                help_text='If disabled, the Server will NEVER ask the user for consent.',
                verbose_name='Require Consent?'),
        ),
        migrations.AddField(
            model_name='client',
            name='reuse_consent',
            field=models.BooleanField(
                default=True,
                help_text="If enabled, the Server will save the user consent given to a specific client,"
                          " so that user won't be prompted for the same authorization multiple times.",
                verbose_name='Reuse Consent?'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10 on 2016-12-12 19:44
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oidc_provider', '0020_client__post_logout_redirect_uris'),
    ]

    operations = [
        migrations.AlterField(
            model_name='token',
            name='refresh_token',
            field=models.CharField(default='', max_length=255, unique=True, verbose_name='Refresh Token'),
            preserve_default=False,
        ),
    ]



DEBUG = False

SECRET_KEY = 'this-should-be-top-secret'

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': ':memory:',
    }
}

SITE_ID = 1

MIDDLEWARE_CLASSES = [
    'django.middleware.common.CommonMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
]

MIDDLEWARE = [
    'django.middleware.common.CommonMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
]

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

INSTALLED_APPS = [
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.messages',
    'django.contrib.admin',
    'oidc_provider',
]

ROOT_URLCONF = 'oidc_provider.tests.app.urls'

TEMPLATE_DIRS = [
    'oidc_provider/tests/templates',
]

USE_TZ = True

LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'handlers': {
        'console': {
            'class': 'logging.StreamHandler',
        },
    },
    'loggers': {
        'oidc_provider': {
            'handlers': ['console'],
            'level': 'DEBUG',
        },
    },
}

# OIDC Provider settings.

SITE_URL = 'http://localhost:8000'
OIDC_USERINFO = 'oidc_provider.tests.app.utils.userinfo'



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('oidc_provider', '0004_remove_userinfo'),
    ]

    operations = [
        migrations.AddField(
            model_name='token',
            name='refresh_token',
            field=models.CharField(max_length=255, unique=True, null=True),
            preserve_default=True,
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-06-10 13:55
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oidc_provider', '0014_client_jwt_alg'),
    ]

    operations = [
        migrations.AlterField(
            model_name='client',
            name='_redirect_uris',
            field=models.TextField(default='', help_text='Enter each URI on a new line.', verbose_name='Redirect URI'),
        ),
        migrations.AlterField(
            model_name='client',
            name='client_secret',
            field=models.CharField(blank=True, default='', max_length=255),
        ),
        migrations.AlterField(
            model_name='client',
            name='client_type',
            field=models.CharField(
                choices=[('confidential', 'Confidential'), ('public', 'Public')],
                default='confidential',
                help_text='<b>Confidential</b> clients are capable of maintaining the confidentiality of their'
                          ' credentials. <b>Public</b> clients are incapable.',
                max_length=30),
        ),
        migrations.AlterField(
            model_name='client',
            name='jwt_alg',
            field=models.CharField(
                choices=[('HS256', 'HS256'), ('RS256', 'RS256')],
                default='RS256',
                max_length=10,
                verbose_name='JWT Algorithm'),
        ),
        migrations.AlterField(
            model_name='client',
            name='name',
            field=models.CharField(default='', max_length=100),
        ),
        migrations.AlterField(
            model_name='client',
            name='response_type',
            field=models.CharField(
                choices=[
                    ('code', 'code (Authorization Code Flow)'), ('id_token', 'id_token (Implicit Flow)'),
                    ('id_token token', 'id_token token (Implicit Flow)')],
                max_length=30),
        ),
        migrations.AlterField(
            model_name='code',
            name='_scope',
            field=models.TextField(default=''),
        ),
        migrations.AlterField(
            model_name='code',
            name='nonce',
            field=models.CharField(blank=True, default='', max_length=255),
        ),
        migrations.AlterField(
            model_name='token',
            name='_scope',
            field=models.TextField(default=''),
        ),
        migrations.AlterField(
            model_name='userconsent',
            name='_scope',
            field=models.TextField(default=''),
        ),
    ]



import copy

from django.utils.translation import gettext_lazy as _

from oidc_provider import settings


STANDARD_CLAIMS = {
    'name': '',
    'given_name': '',
    'family_name': '',
    'middle_name': '',
    'nickname': '',
    'preferred_username': '',
    'profile': '',
    'picture': '',
    'website': '',
    'gender': '',
    'birthdate': '',
    'zoneinfo': '',
    'locale': '',
    'updated_at': '',
    'email': '',
    'email_verified': '',
    'phone_number': '',
    'phone_number_verified': '',
    'address': {
        'formatted': '',
        'street_address': '',
        'locality': '',
        'region': '',
        'postal_code': '',
        'country': '',
    },
}


class ScopeClaims(object):

    def __init__(self, token):
        self.user = token.user
        claims = copy.deepcopy(STANDARD_CLAIMS)
        self.userinfo = settings.get('OIDC_USERINFO', import_str=True)(claims, self.user)
        self.scopes = token.scope
        self.client = token.client

    def create_response_dic(self):
        """
        Generate the dic that will be jsonify. Checking scopes given vs
        registered.

        Returns a dic.
        """
        dic = {}

        for scope in self.scopes:
            if scope in self._scopes_registered():
                dic.update(getattr(self, 'scope_' + scope)())

        dic = self._clean_dic(dic)

        return dic

    def _scopes_registered(self):
        """
        Return a list that contains all the scopes registered
        in the class.
        """
        scopes = []

        for name in dir(self.__class__):
            if name.startswith('scope_'):
                scope = name.split('scope_')[1]
                scopes.append(scope)

        return scopes

    def _clean_dic(self, dic):
        """
        Clean recursively all empty or None values inside a dict.
        """
        aux_dic = dic.copy()
        for key, value in iter(dic.items()):

            if value is None or value == '':
                del aux_dic[key]
            elif type(value) is dict:
                cleaned_dict = self._clean_dic(value)
                if not cleaned_dict:
                    del aux_dic[key]
                    continue
                aux_dic[key] = cleaned_dict
        return aux_dic

    @classmethod
    def get_scopes_info(cls, scopes=None):
        if scopes is None:
            scopes = []
        scopes_info = []

        for name in dir(cls):
            if name.startswith('info_'):
                scope_name = name.split('info_')[1]
                if scope_name in scopes:
                    touple_info = getattr(cls, name)
                    scopes_info.append({
                        'scope': scope_name,
                        'name': touple_info[0],
                        'description': touple_info[1],
                    })

        return scopes_info


class StandardScopeClaims(ScopeClaims):
    """
    Based on OpenID Standard Claims.
    See: http://openid.net/specs/openid-connect-core-1_0.html#StandardClaims
    """

    info_profile = (
        _(u'Basic profile'),
        _(u'Access to your basic information. Includes names, gender, birthdate '
          'and other information.'),
    )

    def scope_profile(self):
        dic = {
            'name': self.userinfo.get('name'),
            'given_name': (self.userinfo.get('given_name') or
                           getattr(self.user, 'first_name', None)),
            'family_name': (self.userinfo.get('family_name') or
                            getattr(self.user, 'last_name', None)),
            'middle_name': self.userinfo.get('middle_name'),
            'nickname': self.userinfo.get('nickname') or getattr(self.user, 'username', None),
            'preferred_username': self.userinfo.get('preferred_username'),
            'profile': self.userinfo.get('profile'),
            'picture': self.userinfo.get('picture'),
            'website': self.userinfo.get('website'),
            'gender': self.userinfo.get('gender'),
            'birthdate': self.userinfo.get('birthdate'),
            'zoneinfo': self.userinfo.get('zoneinfo'),
            'locale': self.userinfo.get('locale'),
            'updated_at': self.userinfo.get('updated_at'),
        }

        return dic

    info_email = (
        _(u'Email'),
        _(u'Access to your email address.'),
    )

    def scope_email(self):
        dic = {
            'email': self.userinfo.get('email') or getattr(self.user, 'email', None),
            'email_verified': self.userinfo.get('email_verified'),
        }

        return dic

    info_phone = (
        _(u'Phone number'),
        _(u'Access to your phone number.'),
    )

    def scope_phone(self):
        dic = {
            'phone_number': self.userinfo.get('phone_number'),
            'phone_number_verified': self.userinfo.get('phone_number_verified'),
        }

        return dic

    info_address = (
        _(u'Address information'),
        _(u'Access to your address. Includes country, locality, street and other information.'),
    )

    def scope_address(self):
        dic = {
            'address': {
                'formatted': self.userinfo.get('address', {}).get('formatted'),
                'street_address': self.userinfo.get('address', {}).get('street_address'),
                'locality': self.userinfo.get('address', {}).get('locality'),
                'region': self.userinfo.get('address', {}).get('region'),
                'postal_code': self.userinfo.get('address', {}).get('postal_code'),
                'country': self.userinfo.get('address', {}).get('country'),
            }
        }

        return dic



# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-11-01 14:59
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oidc_provider', '0019_auto_20161005_1552'),
    ]

    operations = [
        migrations.AddField(
            model_name='client',
            name='_post_logout_redirect_uris',
            field=models.TextField(
                blank=True,
                default='',
                help_text='Enter each URI on a new line.',
                verbose_name='Post Logout Redirect URIs'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-09-12 14:08
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oidc_provider', '0017_auto_20160811_1954'),
    ]

    operations = [
        migrations.AddField(
            model_name='client',
            name='contact_email',
            field=models.CharField(blank=True, default='', max_length=255, verbose_name='Contact Email'),
        ),
        migrations.AddField(
            model_name='client',
            name='logo',
            field=models.FileField(
                blank=True, default='', upload_to='oidc_provider/clients', verbose_name='Logo Image'),
        ),
        migrations.AddField(
            model_name='client',
            name='terms_url',
            field=models.CharField(
                blank=True,
                default='',
                help_text='External reference to the privacy policy of the client.',
                max_length=255,
                verbose_name='Terms URL'),
        ),
        migrations.AddField(
            model_name='client',
            name='website_url',
            field=models.CharField(blank=True, default='', max_length=255, verbose_name='Website URL'),
        ),
        migrations.AlterField(
            model_name='client',
            name='jwt_alg',
            field=models.CharField(
                choices=[('HS256', 'HS256'), ('RS256', 'RS256')],
                default='RS256',
                help_text='Algorithm used to encode ID Tokens.',
                max_length=10,
                verbose_name='JWT Algorithm'),
        ),
        migrations.AlterField(
            model_name='client',
            name='response_type',
            field=models.CharField(
                choices=[
                    ('code', 'code (Authorization Code Flow)'), ('id_token', 'id_token (Implicit Flow)'),
                    ('id_token token', 'id_token token (Implicit Flow)'), ('code token', 'code token (Hybrid Flow)'),
                    ('code id_token', 'code id_token (Hybrid Flow)'),
                    ('code id_token token', 'code id_token token (Hybrid Flow)')],
                max_length=30,
                verbose_name='Response Type'),
        ),
    ]



import os
from setuptools import (
    find_packages,
    setup,
)

version = {}
with open("./oidc_provider/version.py") as fp:
    exec(fp.read(), version)

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-oidc-provider',
    version=version['__version__'],
    packages=find_packages(),
    include_package_data=True,
    license='MIT License',
    description='OpenID Connect Provider implementation for Django.',
    long_description='http://github.com/juanifioren/django-oidc-provider',
    url='http://github.com/juanifioren/django-oidc-provider',
    author='Juan Ignacio Fiorentino',
    author_email='juanifioren@gmail.com',
    zip_safe=False,
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
    test_suite='runtests.runtests',
    tests_require=[
        'pyjwkest>=1.3.0',
        'mock>=2.0.0',
    ],

    install_requires=[
        'pyjwkest>=1.3.0',
    ],
)
